@@ -1,3 +1,7 @@
+#[allow(deprecated)]
+use solana_program::sysvar::recent_blockhashes::{
+    IntoIterSorted, IterItem, RecentBlockhashes, MAX_ENTRIES,
+};
 use {
     crate::{
         account::{
@@ -6,12 +10,14 @@ use {
         },
         clock::INITIAL_RENT_EPOCH,
     },
-    solana_program::sysvar::recent_blockhashes::{
-        IntoIterSorted, IterItem, RecentBlockhashes, MAX_ENTRIES,
-    },
     std::{collections::BinaryHeap, iter::FromIterator},
 };
 
+#[deprecated(
+    since = "1.9.0",
+    note = "Please do not use, will no longer be available in the future"
+)]
+#[allow(deprecated)]
 pub fn update_account<'a, I>(
     account: &mut AccountSharedData,
     recent_blockhash_iter: I,
@@ -20,8 +26,11 @@ where
     I: IntoIterator<Item = IterItem<'a>>,
 {
     let sorted = BinaryHeap::from_iter(recent_blockhash_iter);
+    #[allow(deprecated)]
     let sorted_iter = IntoIterSorted::new(sorted);
+    #[allow(deprecated)]
     let recent_blockhash_iter = sorted_iter.take(MAX_ENTRIES);
+    #[allow(deprecated)]
     let recent_blockhashes: RecentBlockhashes = recent_blockhash_iter.collect();
     to_account(&recent_blockhashes, account)
 }
@@ -30,13 +39,20 @@ where
     since = "1.5.17",
     note = "Please use `create_account_with_data_for_test` instead"
 )]
+#[allow(deprecated)]
 pub fn create_account_with_data<'a, I>(lamports: u64, recent_blockhash_iter: I) -> AccountSharedData
 where
     I: IntoIterator<Item = IterItem<'a>>,
 {
+    #[allow(deprecated)]
     create_account_with_data_and_fields(recent_blockhash_iter, (lamports, INITIAL_RENT_EPOCH))
 }
 
+#[deprecated(
+    since = "1.9.0",
+    note = "Please do not use, will no longer be available in the future"
+)]
+#[allow(deprecated)]
 pub fn create_account_with_data_and_fields<'a, I>(
     recent_blockhash_iter: I,
     fields: InheritableAccountFields,
@@ -52,6 +68,11 @@ where
     account
 }
 
+#[deprecated(
+    since = "1.9.0",
+    note = "Please do not use, will no longer be available in the future"
+)]
+#[allow(deprecated)]
 pub fn create_account_with_data_for_test<'a, I>(recent_blockhash_iter: I) -> AccountSharedData
 where
     I: IntoIterator<Item = IterItem<'a>>,
@@ -61,12 +82,12 @@ where
 
 #[cfg(test)]
 mod tests {
+    #![allow(deprecated)]
     use {
         super::*,
         crate::account::from_account,
         rand::{seq::SliceRandom, thread_rng},
         solana_program::{
-            fee_calculator::FeeCalculator,
             hash::{Hash, HASH_BYTES},
             sysvar::recent_blockhashes::Entry,
         },
@@ -82,9 +103,9 @@ mod tests {
     #[test]
     fn test_create_account_full() {
         let def_hash = Hash::default();
-        let def_fees = FeeCalculator::default();
+        let def_lamports_per_signature = 0;
         let account = create_account_with_data_for_test(
-            vec![IterItem(0u64, &def_hash, &def_fees); MAX_ENTRIES].into_iter(),
+            vec![IterItem(0u64, &def_hash, def_lamports_per_signature); MAX_ENTRIES].into_iter(),
         );
         let recent_blockhashes = from_account::<RecentBlockhashes, _>(&account).unwrap();
         assert_eq!(recent_blockhashes.len(), MAX_ENTRIES);
@@ -93,9 +114,10 @@ mod tests {
     #[test]
     fn test_create_account_truncate() {
         let def_hash = Hash::default();
-        let def_fees = FeeCalculator::default();
+        let def_lamports_per_signature = 0;
         let account = create_account_with_data_for_test(
-            vec![IterItem(0u64, &def_hash, &def_fees); MAX_ENTRIES + 1].into_iter(),
+            vec![IterItem(0u64, &def_hash, def_lamports_per_signature); MAX_ENTRIES + 1]
+                .into_iter(),
         );
         let recent_blockhashes = from_account::<RecentBlockhashes, _>(&account).unwrap();
         assert_eq!(recent_blockhashes.len(), MAX_ENTRIES);
@@ -103,7 +125,7 @@ mod tests {
 
     #[test]
     fn test_create_account_unsorted() {
-        let def_fees = FeeCalculator::default();
+        let def_lamports_per_signature = 0;
         let mut unsorted_blocks: Vec<_> = (0..MAX_ENTRIES)
             .map(|i| {
                 (i as u64, {
@@ -119,13 +141,13 @@ mod tests {
         let account = create_account_with_data_for_test(
             unsorted_blocks
                 .iter()
-                .map(|(i, hash)| IterItem(*i, hash, &def_fees)),
+                .map(|(i, hash)| IterItem(*i, hash, def_lamports_per_signature)),
         );
         let recent_blockhashes = from_account::<RecentBlockhashes, _>(&account).unwrap();
 
         let mut unsorted_recent_blockhashes: Vec<_> = unsorted_blocks
             .iter()
-            .map(|(i, hash)| IterItem(*i, hash, &def_fees))
+            .map(|(i, hash)| IterItem(*i, hash, def_lamports_per_signature))
             .collect();
         unsorted_recent_blockhashes.sort();
         unsorted_recent_blockhashes.reverse();
